Index: /trunk/src/VBox/Devices/Bus/DevPCI.cpp
===================================================================
--- /trunk/src/VBox/Devices/Bus/DevPCI.cpp	(revision 41815)
+++ /trunk/src/VBox/Devices/Bus/DevPCI.cpp	(revision 41816)
@@ -244,5 +244,5 @@
 /**
  * Reads data via bus mastering, if enabled. If no bus mastering is available,
  * this function does nothing and returns VINF_SUCCESS.
  *
  * @return  IPRT status code.
@@ -260,5 +260,5 @@
               PCIDevGetVendorId(pPciDev), PCIDevGetDeviceId(pPciDev), pvBuf, cbRead));
 #endif
-        return VINF_SUCCESS;
+        return VINF_NOT_SUPPORTED;
     }
 
@@ -268,5 +268,5 @@
 /**
  * Writes data via bus mastering, if enabled. If no bus mastering is available,
  * this function does nothing and returns VINF_SUCCESS.
  *
  * @return  IPRT status code.
@@ -284,5 +284,5 @@
               PCIDevGetVendorId(pPciDev), PCIDevGetDeviceId(pPciDev), pvBuf, cbWrite));
 #endif
-        return VINF_SUCCESS;
+        return VINF_NOT_SUPPORTED;
     }
 
@@ -244,5 +244,5 @@
 /**
  * Reads data via bus mastering, if enabled. If no bus mastering is available,
- * this function does nothing and returns VINF_SUCCESS.
+ * this function does nothing and returns VINF_NOT_SUPPORTED.
  *
  * @return  IPRT status code.
@@ -268,5 +268,5 @@
 /**
  * Writes data via bus mastering, if enabled. If no bus mastering is available,
- * this function does nothing and returns VINF_SUCCESS.
+ * this function does nothing and returns VINF_NOT_SUPPORTED.
  *
  * @return  IPRT status code.
